SessionInfo class
Represents an active user session.
Constructors
- SessionInfo({required String handle, String? userAgent, String? ipAddress, DateTime? createdAt, DateTime? lastActiveAt, bool isCurrent = false})
-
const
-
SessionInfo.fromJson(Map<
String, dynamic> json) -
factory
Properties
- createdAt → DateTime?
-
Timestamp when this session was created.
final
- handle → String
-
Unique session handle used to identify and revoke this session.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- ipAddress → String?
-
IP address from which this session was created.
final
- isCurrent → bool
-
Whether this is the currently active session for the authenticated user.
final
- lastActiveAt → DateTime?
-
Timestamp of the last activity for this session.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userAgent → String?
-
User-agent string of the browser or client that created this session.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited